[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
02/02: tests: Adjust 'guix package' test to "python2" name.
From: |
Ludovic Courtès |
Subject: |
02/02: tests: Adjust 'guix package' test to "python2" name. |
Date: |
Wed, 6 Jun 2018 08:37:49 -0400 (EDT) |
civodul pushed a commit to branch core-updates
in repository guix.
commit 477ee222aa796257b5f32966da662e76fe706332
Author: Ludovic Courtès <address@hidden>
Date: Wed Jun 6 14:26:09 2018 +0200
tests: Adjust 'guix package' test to "python2" name.
This is a followup to a7714d42de2c3082f3609d1e63c83d703fb39cf9, which
renamed Python 2.x to "python2".
* tests/guix-package.sh: Use g-wrap and address@hidden when testing
collisions.
---
tests/guix-package.sh | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
diff --git a/tests/guix-package.sh b/tests/guix-package.sh
index aa5eaa6..3b3fa35 100644
--- a/tests/guix-package.sh
+++ b/tests/guix-package.sh
@@ -60,12 +60,12 @@ test -L "$profile" && test -L "$profile-1-link"
! test -f "$profile-2-link"
test -f "$profile/bin/guile"
-# Collisions are properly flagged (in this case, 'python-wrapper' propagates
-# address@hidden, which conflicts with address@hidden)
-if guix package --bootstrap -n -p "$profile" -i address@hidden python-wrapper
+# Collisions are properly flagged (in this case, 'g-wrap' propagates
+# address@hidden, which conflicts with address@hidden)
+if guix package --bootstrap -n -p "$profile" -i g-wrap address@hidden
then false; else true; fi
-guix package --bootstrap -n -p "$profile" -i address@hidden python-wrapper \
+guix package --bootstrap -n -p "$profile" -i g-wrap address@hidden \
--allow-collisions
# No search path env. var. here.